function [T,Y] = heun(f,a,b,ya,m)
%---------------------------------------------------------------------------
%TAYLOR    Taylor's solution for y' = f(t,y) with y(a) = ya.
% Sample call
%   [T,Y] = taylor('f',a,b,ya,m)
% Inputs
%   f    name of the function
%   a    left  endpoint of [a,b]
%   b    right endpoint of [a,b]
%   ya   initial value
%   m    number of steps
% Return
%   T    solution: vector of abscissas
%   Y    solution: vector of ordinates
%
% 
%---------------------------------------------------------------------------

h = (b - a)/m;
T = zeros(1,m+1);
Y = zeros(1,m+1);
T = a:h:b;
Y(1) = ya;

for J = 1:m;
    k1 = feval(f, T(J), Y(J));
    k2 = feval(f, T(J+1), Y(J) + h * k1);
    Y(J+1) = Y(J) + h * (k1 + k2) / 2;
end
